@@ -1,4 +1,4 @@
-/*	$Id: HDLCFrame.h,v 1.5 2003/09/20 16:05:06 lhoward Exp $ */
+/*	$Id: HDLCFrame.h,v 1.6 2005/01/25 22:35:28 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -29,6 +29,7 @@
  * Raw HDLC Frame Interface.
  */
 #include "Types.h"
+#include "FaxParams.h"
 
 class HDLCFrame {
 public:
@@ -56,8 +57,7 @@ public:
     const u_char* getFrameData() const;	// data following FCF
     u_int getFrameDataLength() const;	// length of data - (FCF+FCS)
     u_int getDataWord() const;		// first 0-4 bytes of data
-    u_int getDIS() const;		// DIS/DCS data
-    u_int getXINFO() const;		// extended info after DIS/DCS
+    FaxParams getDIS() const;	// DIS/DCS data
 protected:
     u_char	buf[2048];		// large enough for TCF at 9600 baud
     u_char*	next;
