@@ -1,4 +1,4 @@
-/*	$Id: faxQueueApp.h,v 1.26 2006/07/03 21:08:32 aidan Exp $ */
+/*	$Id: faxQueueApp.h,v 1.36 2007/07/23 21:04:09 aidan Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -32,6 +32,7 @@
 #include "FaxConfig.h"
 #include "IOHandler.h"
 #include "Job.h"
+#include "Batch.h"
 #include "DestInfo.h"
 #include "JobControl.h"
 #include "StrDict.h"
@@ -44,6 +45,7 @@ class UUCPLock;
 class FaxItem;
 class Modem;
 class Trigger;
+class Status;
 
 /*
  * This class represents a thread of control that manages the
@@ -122,7 +124,6 @@ private:
     fxStr	sendUUCPCmd;		// external command for UUCP calls
     fxStr	wedgedCmd;		// external command for wedged modems
     fxStr	jobCtrlCmd;		// external command for JobControl
-    bool	jobCtrlWait;		// Wait syncronously for JobControl to finish
 
     static stringtag strings[];
     static numbertag numbers[];
@@ -132,12 +133,12 @@ private:
     bool	abortPrepare;		// job preparation should be aborted
     bool	quit;			// terminate server
     int		fifo;			// fifo job queue interface
-#define	NQHASH		16
-    QLink	runqs[NQHASH];		// jobs ready to run
-    QLink	sleepq;			// jobs waiting for time-to-send
-    QLink	activeq;		// jobs actively being processed
+    QLink	runq;			// list of DestInfo ready to run
+    QLink	destq;			// list of DestInfo with no ready jobs
+    QLink	batchq;			// batches actively being processed
     QLink	deadq;			// jobs waiting to be reaped
     QLink	suspendq;		// jobs suspending from scheduling
+    QLink	jcontrolq;		// jobs actively running jobcontrol
     SchedTimeout schedTimeout;		// timeout for running scheduler
     DestInfoDict destJobs;		// jobs organized by destination
     fxStrDict	pendingDocs;		// documents waiting for removal
@@ -151,9 +152,8 @@ private:
 
     friend class JobTTSHandler;		// for access to runJob
     friend class JobKillHandler;	// for acccess to timeoutJob
-    friend class JobPrepareHandler;	// for acccess to prepareJobDone
-    friend class JobSendHandler;	// for acccess to sendJobDone
     friend class JobCtrlHandler;	// for acccess to ctrlJobDone
+    friend class Batch;			// for acccess to prepareDone and senddone
     friend class faxQueueApp::SchedTimeout;// for access to runScheduler
     friend class ModemLockWaitHandler;	// for access to pollForModemLock
 
@@ -168,13 +168,14 @@ private:
 // modem support
     void	scanForModems();
     bool	assignModem(Job& job);
-    void	releaseModem(Job& job);
+    void	releaseModem(Modem& modem);
     void	notifyModemWedged(Modem&);
     void	pollForModemLock(Modem& modem);
 // diagnostic and tracing interfaces
     void	traceServer(const char* fmt ...);
     void	vtraceServer(const char* fmt, va_list ap);
     void	jobError(const Job& job, const char* fmt ...);
+    void	traceQueue(const DestInfo&, const char* fmt ...);
     void	traceQueue(const Job&, const char* fmt ...);
     void	traceJob(const Job&, const char* fmt ...);
     void	traceQueue(const char* fmt ...);
@@ -182,7 +183,7 @@ private:
 // miscellaneous stuff
     void	startTimeout(long ms);
     void	stopTimeout(const char* whichdir);
-    const fxStr& pickCmd(const FaxRequest& req);
+    const fxStr& pickCmd(const fxStr& jobtype);
 // FIFO-related stuff
     void	childStatus(pid_t, int);	// Dispatcher hook
     int		inputReady(int);		// Dispatcher hook
@@ -204,25 +205,30 @@ private:
 		    bool force, const char* duration = "");
     void	notifySender(Job&, JobStatus, const char* = "");
 // job management interfaces
+    bool	isJobSendOK(Job& job, FaxRequest* req);
     void	processJob(Job& job);
-    void	processJob(Job&, FaxRequest* req, DestInfo& di);
-    void	sendJobStart(Job&, FaxRequest*);
-    void	sendJobDone(Job& job, int status);
+    void	processJob(Batch&, Job&, FaxRequest* req);
     void	sendJobDone(Job& job, FaxRequest* req);
-    void	blockJob(Job&, FaxRequest&, const char*);
-    void	delayJob(Job&, FaxRequest&, const char*, time_t);
-    void	rejectJob(Job& job, FaxRequest& req, const fxStr& reason);
+    void	doneJob(Job& job);
+    void	blockJob(Job&, FaxRequest&, const Status&);
+    void	delayJob(Job&, FaxRequest&, const Status&, time_t);
+    void	rejectJob(Job& job, FaxRequest& req, const Status&);
     bool	submitJob(const fxStr& jobid, bool checkState = false);
     bool	suspendJob(const fxStr& jobid, bool abortActive);
-    void	rejectSubmission(Job&, FaxRequest&, const fxStr& reason);
-    bool	areBatchable(Job& job, Job& nextjob, FaxRequest& nextreq);
-    void	batchJob(Job* prevjob, Job* nextjob, FaxRequest* nextreq);
+    void	rejectSubmission(Job&, FaxRequest&, const Status&);
 
-    void	setReadyToRun(Job& job, bool wait);
-    void	setReady(Job& job);
+    void	startBatch(Modem*, Job&, FaxRequest*, DestInfo&);
+    void	fillBatch (Batch&);
+    bool	canJobBatch(Batch& batch, Job& job, FaxRequest* req);
+
+    void	sendStart(Batch&);
+    void	sendDone(Batch&, int status);
+
+    void	setReadyToRun(Job& job, FaxRequest& req);
+    void	setReady(Job& job, FaxRequest& req);
     void	setSleep(Job& job, time_t tts);
     void	setDead(Job& job);
-    void	setActive(Job& job);
+    void	setActive(Batch& batch, Job& job);
     void	setSuspend(Job& job);
     bool	submitJob(FaxRequest&, bool checkState = false);
     bool	submitJob(Job& job, FaxRequest& req, bool checkState = false);
@@ -233,9 +239,6 @@ private:
     void	timeoutJob(Job& job, FaxRequest&);
     void	runJob(Job& job);
 
-    void	removeDestInfoJob(Job& job);
-    void        unblockDestJobs(DestInfo& di);
-
     bool	scheduling();
     void	runScheduler();
     void	pokeScheduler(u_short s = 0);
@@ -244,21 +247,20 @@ private:
 // job preparation stuff
     bool	prepareJobNeeded(Job&, FaxRequest&, JobStatus&);
     static void prepareCleanup(int s);
-    bool	prepareJobStart(Job&, FaxRequest*,
-		    FaxMachineInfo&);
-    void	prepareJobDone(Job&, int status);
+    void	prepareStart(Batch&, Job&, FaxRequest*);
+    void	prepareDone(Batch&, int status);
     JobStatus	prepareJob(Job& job, FaxRequest& req,
 		    const FaxMachineInfo&);
     JobStatus	convertDocument(Job&,
 		    const FaxItem& input, const fxStr& outFile,
 		    const Class2Params& params,
-		    fxStr& emsg);
+		    Status&);
     JobStatus	runConverter(Job& job, const char* app, char* const* argv,
-		    fxStr& emsg);
+		    Status&);
     bool	runConverter1(Job& job, int fd, fxStr& output);
     void	makeCoverPage(Job&, FaxRequest&, const Class2Params&);
     bool	preparePageHandling(Job&, FaxRequest&,
-		    const FaxMachineInfo&, fxStr& emsg);
+		    const FaxMachineInfo&, Status&);
     void	preparePageChop(const FaxRequest&,
 		    TIFF*, const Class2Params&, fxStr&);
     void	setupParams(TIFF*, Class2Params&, const FaxMachineInfo&);
@@ -270,9 +272,12 @@ public:
 
     static faxQueueApp& instance();
 
+
     void	initialize(int argc, char** argv);
     void	open();
 
+    void	showDebugState();
+
     // NB: public for use by Modem class
     UUCPLock*	getUUCPLock(const fxStr& deviceName);
 
